@@ -62,7 +62,7 @@ QString ArchDoc::docIdentifier() const
 {
   QString re = docTypeStr();
 
-  return i18n("%1 for %2 (Id %3)", re, ident() );
+  return i18n("%1 for %2 (ID %3)", re, ident() );
 }
 
 QString ArchDoc::dateStr() const
@@ -301,6 +301,14 @@ ArchDocDigest ArchDoc::toDigest() const
     return ArchDocDigest(mPrintDate, mState, mIdent, mDocTypeStr, mArchDocID);
 }
 
+bool ArchDoc::isInvoice()
+{
+    bool re{false};
+
+    re = true;
+    return re;
+}
+
 /* ###################################################################### */
 
 ArchDocDigest::ArchDocDigest()
@@ -333,13 +341,6 @@ QString ArchDocDigest::pdfArchiveFileName() const
     return file;
 }
 
-bool ArchDocDigest::isInvoice() const
-{
-    // This is just a work around and should be fixed with an attribute for the doctype
-    // at some point.
-    return (mDocTypeStr == QStringLiteral("Rechnung"));
-}
-
 /* ###################################################################### */
 
 
