@@ -62,12 +62,8 @@ public:
     }
 
     QString pdfArchiveFileName() const;
-
-    // FIXME: This is a workaround for the XRechnung - so far only the german
-    // doctype "Rechnung" enables the XRechnung support.
-    bool isInvoice() const;
-
 protected:
+
     QDateTime mPrintDate;
     int       mState;
     dbID      mArchDocId;
@@ -127,8 +123,6 @@ class ArchDoc: public QObject, public ArchDocDigest
 
 public:
 
-    const QString SentOutDateC {"SentOutDate"};
-
     /** Constructor for the fileclass of the application */
     ArchDoc();
     ArchDoc( const dbID& );
@@ -198,7 +192,7 @@ public:
 
     static QString taxMarkerNoTax()   { return QStringLiteral("1"); }
     static QString taxMarkerReduced() { return QStringLiteral("2"); }
-    static QString taxMarkerFull()    { return QStringLiteral("");  }
+    static QString taxMarkerFull()    { return QString();  }
 
     bool hasIndividualTaxation() const { return mPositions.hasIndividualTaxes(); }
 
@@ -213,6 +207,9 @@ public:
 
     void loadFromDb( dbID );
 
+    bool isInvoice();
+    const QString SentOutDateC {"SentOutDate"};
+
 protected:
     void loadItems( const QString& );
 
@@ -227,6 +224,8 @@ protected:
     QString mProjectLabel;
     QString mPredecessor;
 
+    AttributeMap mAttributes;
+
     QString _buyerRef;
     QDate _dueDate;
 
@@ -236,7 +235,6 @@ protected:
     QDate     mDate;
 
     ArchDocPositionList mPositions;
-    AttributeMap mAttributes;
 };
 
 
