@@ -39,6 +39,8 @@ public:
 
   static DefaultProvider *self();
 
+  QIcon icon(const QString& name);
+
   QString defaultText( const QString&, KraftDoc::Part, DocGuardedPtr = 0 );
   dbID saveDocumentText( const DocText& );
   void deleteDocumentText( const DocText& );
@@ -51,8 +53,7 @@ public:
   QLocale* locale();
 
   QString iconvTool() const;
-  QStringList findTrml2Pdf() const;
-  QString locateKraftTool(const QString& toolName) const;
+  QStringList locatePythonTool(const QString& toolName) const;
   QString locateBinary(const QString& name) const;
   QString locateFile(const QString& findFile) const;
 
