@@ -202,9 +202,6 @@ KraftDB *KraftDB::self()
 
 void KraftDB::close()
 {
-    QString name = m_db.connectionName();
-    // qDebug () << "Database connection name to close: " << name;
-
     m_db.close();
 }
 
