@@ -48,7 +48,6 @@ class KraftDoc : public QObject
     Q_PROPERTY(QString projectLabel READ projectLabel)
     Q_PROPERTY(QString docIDStr READ docIdStr)
     Q_PROPERTY(QString docIdentifier READ docIdentifier)
-    Q_PROPERTY(QString postText READ postText)
 
     Q_PROPERTY(QString nettoSumStr READ nettoSumStr)
     Q_PROPERTY(QString bruttoSumStr READ bruttoSumStr)
@@ -118,11 +117,20 @@ public:
     QString goodbye() const   { return mGoodbye;    }
     void setGoodbye( const QString& str ) { mGoodbye = str; }
 
-    QString preText() const   { return mPreText;  }
-    void setPreText( const QString& str ) { mPreText = str; }
+    // take a string with macros and generate the text replacements for the macros
+    // with the help of the position list
+    QString resolveMacros(const QString& txtWithMacros, const DocPositionList dposList, const QDate &date, double fullTax, double redTax) const;
 
-    QString postText() const { return mPostText; }
-    void setPostText( const QString& str ) { mPostText = str; }
+    // preText is the variant with expanded macros
+    QString preText() const;
+    // preTextRaw is the variant with macros not expanded
+    QString preTextRaw() const;
+    void setPreTextRaw( const QString& str ) { mPreText = str; }
+
+    QString postText() const;
+    // postTextRaw is the variant with macros not expanded
+    QString postTextRaw() const;
+    void setPostTextRaw( const QString& str ) { mPostText = str; }
 
     QString whiteboard() const { return mWhiteboard; }
     void setWhiteboard( const QString& w ) { mWhiteboard = w; }
@@ -177,6 +185,7 @@ private:
     QString mAddressUid;
     QString mProjectLabel;
     QString mAddress;
+    // mPreText and postText always have the raw variant without expanded macros
     QString mPreText;
     QString mPostText;
     QString mDocType;
