@@ -113,14 +113,14 @@ DocDetailsPage::DocDetailsPage( QWidget *parent )
   mTypeCombo = new QComboBox;
   mTypeCombo->insertItems( 0, DocType::allLocalised() );
   mTypeCombo->setCurrentIndex( mTypeCombo->findText( DefaultProvider::self()->docType() ));
-  grid->addRow( i18n("Document &Type:"), mTypeCombo );
+  grid->addRow( i18n("Document &type:"), mTypeCombo );
 
   mDateEdit = new QDateEdit;
   mDateEdit->setDate( QDate::currentDate() );
-  grid->addRow( i18n( "Document Date: " ), mDateEdit );
+  grid->addRow( i18n( "Document date: " ), mDateEdit );
 
   mWhiteboardEdit = new QTextEdit;
-  grid->addRow( i18n( "Whiteboard Content:" ), mWhiteboardEdit );
+  grid->addRow( i18n( "Whiteboard content:" ), mWhiteboardEdit );
 
   QHBoxLayout *hbox = new QHBoxLayout;
   vbox->addLayout(hbox);
@@ -179,12 +179,12 @@ void KraftWizard::init( bool haveAddressSelect, const QString& followUpDoc )
 
     mDetailsPage = new DocDetailsPage();
     addPage(mDetailsPage);
-    // w1, QLatin1Literal("<h2>") +  + QLatin1Literal("</h2>") );
+    // w1, QLatin1String("<h2>") +  + QLatin1String("</h2>") );
 
     // only pick an addressee if the document is really new
     if( addressProvider->backendUp() && haveAddressSelect ) {
         mCustomerPage = new CustomerSelectPage( );
-        addPage( mCustomerPage); // w, QLatin1Literal("<h2>") + i18n( "Select an Addressee" ) + QLatin1Literal("</h2>") );
+        addPage( mCustomerPage); // w, QLatin1String("<h2>") + i18n( "Select an Addressee" ) + QLatin1String("</h2>") );
 
         mCustomerPage->setupAddresses();
         connect( mCustomerPage, SIGNAL( addresseeSelected(KContacts::Addressee)),
