@@ -25,11 +25,9 @@
 #include <qdrawutil.h>
 
 #include "positionviewwidget.h"
-#include "unitmanager.h"
 #include "geld.h"
 #include "kraftsettings.h"
 #include "defaultprovider.h"
-#include "kraftdb.h"
 #include "itemtagdialog.h"
 #include "tagman.h"
 
@@ -65,9 +63,9 @@ PositionViewWidget::PositionViewWidget()
   mDiscountPercent->setDecimals( 2 );
 
   pbExec->setCheckable( false );
-  pbExec->setIcon( QIcon::fromTheme( "configure") );
+  pbExec->setIcon( DefaultProvider::self()->icon( "tool") );
   pbTagging->setCheckable( false );
-  pbTagging->setIcon( QIcon::fromTheme( "flag" ) );
+  pbTagging->setIcon( DefaultProvider::self()->icon( "flag" ) );
 
   connect( m_sbAmount, SIGNAL( valueChanged( double )),
              this, SLOT( slotRefreshPrice( ) ) );
@@ -94,9 +92,9 @@ PositionViewWidget::PositionViewWidget()
   // state submenu:
   mStateSubmenu = mExecPopup->addMenu(i18n( "Item Kind" ));
   mStateSubmenu->addAction( i18n( "Normal" ), this, SIGNAL( positionStateNormal() ) );
-  mStateSubmenu->addAction( QIcon::fromTheme( "kraft_alternative" ),
+  mStateSubmenu->addAction( DefaultProvider::self()->icon( "arrow-ramp-right" ),
                             i18n( "Alternative" ), this, SIGNAL( positionStateAlternative() ) );
-  mStateSubmenu->addAction( QIcon::fromTheme( "kraft_demand" ),
+  mStateSubmenu->addAction( DefaultProvider::self()->icon( "arrow-move-right" ),
                             i18n( "On Demand" ), this, SIGNAL( positionStateDemand() ) );
 
   // mExecPopup->addSeparator();
@@ -105,19 +103,19 @@ PositionViewWidget::PositionViewWidget()
   mTaxSubmenu = mExecPopup->addMenu(i18n( "Tax" ));
   QActionGroup *agroup = new QActionGroup( this );
   agroup->setExclusive ( true );
-  mNilTaxAction = new QAction( QIcon::fromTheme("kraft_notax"),  i18n("Taxfree Item"), this );
+  mNilTaxAction = new QAction( DefaultProvider::self()->icon("circle-0"),  i18n("Taxfree Item"), this );
   connect( mNilTaxAction, SIGNAL(triggered()), this, SLOT(slotSetNilTax()) );
   mNilTaxAction->setCheckable( true );
   agroup->addAction( mNilTaxAction );
   mTaxSubmenu->addAction( mNilTaxAction );
 
-  mRedTaxAction = new QAction( QIcon::fromTheme("kraft_redtax"), i18n("Reduced Tax"),  this );
+  mRedTaxAction = new QAction( DefaultProvider::self()->icon("circle-half-2"), i18n("Reduced Tax"),  this );
   connect( mRedTaxAction, SIGNAL(triggered()), this, SLOT(slotSetReducedTax()));
   mRedTaxAction->setCheckable( true );
   agroup->addAction( mRedTaxAction );
   mTaxSubmenu->addAction( mRedTaxAction );
 
-  mFullTaxAction = new QAction( QIcon::fromTheme("kraft_fulltax"), i18n("Full Tax"),  this );
+  mFullTaxAction = new QAction( DefaultProvider::self()->icon("coin"), i18n("Full Tax"),  this );
   connect( mFullTaxAction, SIGNAL(triggered()), this, SLOT(slotSetFullTax()));
   mFullTaxAction->setCheckable( true );
   agroup->addAction( mFullTaxAction );
@@ -125,28 +123,38 @@ PositionViewWidget::PositionViewWidget()
 
   mExecPopup->addSeparator();
 
-  mExecPopup->addAction(  QIcon::fromTheme("arrow-up"),
+  mExecPopup->addAction(  DefaultProvider::self()->icon("arrow-up"),
                            i18n("Move Up"),         this, SIGNAL( moveUp() ) );
-  mExecPopup->addAction(  QIcon::fromTheme("arrow-down"),
+  mExecPopup->addAction(  DefaultProvider::self()->icon("arrow-down"),
                            i18n("Move Down"),       this, SIGNAL( moveDown() ) );
-  mLockId = mExecPopup->addAction(  QIcon::fromTheme("object-locked"),
+  mLockId = mExecPopup->addAction(  DefaultProvider::self()->icon("lock"),
                            i18n("Lock Item"),   this, SIGNAL( lockPosition() ) );
-  mUnlockId = mExecPopup->addAction(  QIcon::fromTheme("object-unlocked"),
+  mUnlockId = mExecPopup->addAction(  DefaultProvider::self()->icon("lock-open"),
                            i18n("Unlock Item"), this, SIGNAL( unlockPosition() ) );
-  mDeleteId = mExecPopup->addAction(  QIcon::fromTheme("edit-delete"),
+  mDeleteId = mExecPopup->addAction(  DefaultProvider::self()->icon("minus"),
                            i18n("Delete Item"), this, SIGNAL( deletePosition() ) );
 
+  connect(this, &PositionViewWidget::positionStateNormal, this, [this]() {
+      slotSetPositionKind(Normal, true);
+      slotRefreshPrice();
+      emit positionModified();
+  } );
+  connect(this, &PositionViewWidget::positionStateAlternative, this, [this]() {
+      slotSetPositionKind(Alternative, true);
+      slotRefreshPrice();
+      emit positionModified();
+  } );
+  connect(this, &PositionViewWidget::positionStateDemand, this, [this]() {
+      slotSetPositionKind(Demand, true);
+      slotRefreshPrice();
+      emit positionModified();
+  } );
 
-  connect( this, SIGNAL( positionStateNormal() ), this, SLOT( slotSetPositionNormal() ) );
-  connect( this, SIGNAL( positionStateAlternative() ), this, SLOT( slotSetPositionAlternative() ) );
-  connect( this, SIGNAL( positionStateDemand() ), this, SLOT( slotSetPositionDemand() ) );
+  connect(this, &PositionViewWidget::lockPosition, this, &PositionViewWidget::slotLockPosition);
+  connect(this, &PositionViewWidget::unlockPosition, this, &PositionViewWidget::slotUnlockPosition);
 
-
-  connect( this, SIGNAL( lockPosition() ),   this, SLOT( slotLockPosition() ) );
-  connect( this, SIGNAL( unlockPosition() ), this, SLOT( slotUnlockPosition() ) );
-
-  connect( mExecPopup, SIGNAL( aboutToShow() ), this, SLOT( slotMenuAboutToShow() ) );
-  connect( mExecPopup, SIGNAL( aboutToHide() ), this, SLOT( slotMenuAboutToHide() ) );
+  connect( mExecPopup, &QMenu::aboutToShow, this, &PositionViewWidget::slotMenuAboutToShow);
+  connect( mExecPopup, &QMenu::aboutToHide, this, &PositionViewWidget::slotMenuAboutToHide);
 
   mUnlockId->setEnabled(false);
   lStatus->setPixmap( QPixmap() );
@@ -160,17 +168,18 @@ PositionViewWidget::PositionViewWidget()
 void PositionViewWidget::setDocPosition( DocPositionBase *dp)
 {
   if( ! dp ) {
-    qCritical() << "setDocPosition got empty position!" << endl;
+    qCritical() << "setDocPosition got empty position!";
     return;
   }
 
   DocPosition *pos = static_cast<DocPosition*>(dp);
 
+  // FIXME: Do not keep this pointer ...
   mPositionPtr = pos;
 
   m_skipModifiedSignal = true;
 
-  m_teFloskel->setText( pos->text() );
+  m_teFloskel->setPlainText( pos->text() );
 
   lStatus->hide();
   lKind->hide();
@@ -191,30 +200,26 @@ void PositionViewWidget::setDocPosition( DocPositionBase *dp)
     m_sbUnitPrice->setValue( pos->unitPrice().toDouble() );
     m_sbUnitPrice->blockSignals( false );
 
-    if ( amap.contains( DocPosition::Kind ) ) {
-      Attribute kind = amap[DocPosition::Kind];
-      const QString kindStr = kind.value().toString();
-      if ( kindStr == kindString( Normal ) ) {
-          slotSetPositionNormal();
-      } else if ( kindStr == kindString( Alternative ) ) {
-        slotSetPositionAlternative();
-      } else if ( kindStr == kindString( Demand ) ) {
-        slotSetPositionDemand();
-      } else {
-        // qDebug () << "Unknown position kind!" << endl;
-      }
+    if ( amap.containsUndeleted( DocPosition::Kind ) ) {
+      Attribute kindAttr = amap[DocPosition::Kind];
+      const QString kindStr = kindAttr.value().toString();
+      Kind kind = techStringToKind(kindStr);
+      slotSetPositionKind(kind, false);
+    } else {
+        slotSetPositionKind(Kind::Normal, false);
     }
-    // qDebug () << "Setting position ptr. in viewwidget: " << pos << endl;
+    // qDebug () << "Setting position ptr. in viewwidget: " << pos;
   } else if ( dp->type() == DocPositionBase::ExtraDiscount ) {
     positionDetailStack->setCurrentWidget( discountPage );
-    // qDebug() << " " << dp->type()<< endl;
+    // qDebug() << " " << dp->type();
     Attribute discount = amap[DocPosition::Discount];
     mDiscountPercent->setValue( discount.value().toDouble() );
 
     QString selTag;
     if ( amap.contains( DocPosition::ExtraDiscountTagRequired ) ) {
       Attribute tagSelector = amap[DocPosition::ExtraDiscountTagRequired];
-      selTag = tagSelector.value().toString();
+      const TagTemplate tt = TagTemplateMan::self()->getTagTemplateFromId(tagSelector.value().toString());
+      selTag = tt.name();
     }
 
     /* Fill and set the extra discount selection combo */
@@ -236,7 +241,7 @@ void PositionViewWidget::setDocPosition( DocPositionBase *dp)
     }
     mDiscountTag->setCurrentIndex(mDiscountTag->findText( currentEntry ));
   } else {
-    // qDebug () << "unknown doc position type " << dp->type()<< endl;
+    // qDebug () << "unknown doc position type " << dp->type();
   }
   slotSetOverallPrice( currentPrice() );
 
@@ -296,7 +301,7 @@ QString PositionViewWidget::extraDiscountTagRestriction()
 
 void PositionViewWidget::slotTaggingButtonPressed()
 {
-  // qDebug () << "opening tagging dialog" << endl;
+  // qDebug () << "opening tagging dialog";
 
   ItemTagDialog dia( 0 );
 
@@ -306,7 +311,7 @@ void PositionViewWidget::slotTaggingButtonPressed()
     slotUpdateTagToolTip();
     slotModified();
     update();
-    // qDebug () << "Selected tags: " << mTags.join( ", " ) << endl;
+    // qDebug () << "Selected tags: " << mTags.join( ", " );
   }
 }
 
@@ -331,17 +336,17 @@ void PositionViewWidget::slotSetTax( DocPosition::TaxType tt )
 
   QString icon;
   if( tt == DocPositionBase::TaxFull ) {
-    icon = QString::fromLatin1("kraft_fulltax");
+    icon = QString::fromLatin1("coin");
     mFullTaxAction->setChecked( true );
   } else if( tt == DocPositionBase::TaxReduced ) {
-    icon = QString::fromLatin1("kraft_redtax");
+    icon = QString::fromLatin1("circle-half-2");
     mRedTaxAction->setChecked( true );
   } else if( tt == DocPositionBase::TaxNone ) {
-    icon = QString::fromLatin1("kraft_notax");
+    icon = QString::fromLatin1("circle-0");
     mNilTaxAction->setChecked( true );
   }
 
-  mTaxSubmenu->setIcon( QIcon::fromTheme( icon ));
+  mTaxSubmenu->setIcon( DefaultProvider::self()->icon( icon ));
   emit positionModified();
 }
 
@@ -360,7 +365,7 @@ DocPositionBase::TaxType PositionViewWidget::taxType() const
 
 void PositionViewWidget::slotExecButtonPressed()
 {
-  // qDebug () << "Opening Context Menu over exec button" << endl;
+  // qDebug () << "Opening Context Menu over exec button";
 
   // set bg-color
   mExecPopup->popup( QWidget::mapToGlobal( pbExec->pos() ) );
@@ -376,7 +381,7 @@ void PositionViewWidget::slotMenuAboutToShow()
 
 void PositionViewWidget::slotMenuAboutToHide()
 {
-  // qDebug () << "Set normal again" << endl;
+  // qDebug () << "Set normal again";
   QPalette palette;
   setPalette( palette );
   pbExec->setChecked(false);
@@ -418,7 +423,7 @@ QString PositionViewWidget::stateString( const State& state ) const
 void PositionViewWidget::slotSetState( State state )
 {
   mState = state;
-  // qDebug () << "Setting new widget state " << stateString( state ) << endl;
+  // qDebug () << "Setting new widget state " << stateString( state );
   if( state == Active ) {
     mLockId->setEnabled( true );
     mUnlockId->setEnabled( false );
@@ -428,10 +433,10 @@ void PositionViewWidget::slotSetState( State state )
     mToDelete = false;
     slotSetEnabled( true );
   } else if( state == New ) {
-    lStatus->setPixmap( QIcon::fromTheme("filenew").pixmap(QSize(20,20)));
+    lStatus->setPixmap( DefaultProvider::self()->icon("file-plus").pixmap(QSize(20,20)));
     lStatus->show();
   } else if( state == Deleted ) {
-    lStatus->setPixmap( QIcon::fromTheme( "remove" ).pixmap(QSize(20,20)) );
+    lStatus->setPixmap( DefaultProvider::self()->icon( "minus" ).pixmap(QSize(20,20)) );
     lStatus->show();
     mToDelete = true;
     slotSetEnabled( false );
@@ -439,7 +444,7 @@ void PositionViewWidget::slotSetState( State state )
     mLockId->setEnabled( false );
     mUnlockId->setEnabled( true );
     slotSetEnabled( false );
-    lStatus->setPixmap( QIcon::fromTheme( "encrypted" ).pixmap(QSize(20,20)));
+    lStatus->setPixmap( DefaultProvider::self()->icon( "lock" ).pixmap(QSize(20,20)));
     lStatus->show();
   }
 }
@@ -502,7 +507,7 @@ Geld PositionViewWidget::currentPrice()
     if ( position()->type() == DocPosition::ExtraDiscount ) {
       sum = mPositionPrice;
       if ( ! mPositionPriceValid ) {
-        qWarning() << "Asking for price of Discount item, but invalid!" << endl;
+        qWarning() << "Asking for price of Discount item, but invalid!";
       }
     } else {
       double amount = m_sbAmount->value();
@@ -539,7 +544,7 @@ void PositionViewWidget::slotModified( bool emitSignal )
 {
     Q_UNUSED(emitSignal)
   if(m_skipModifiedSignal) return;
-  // qDebug () << "Modified Position!" << endl;
+  // qDebug () << "Modified Position!";
 
   mModified = true;
 
@@ -583,88 +588,99 @@ Geld PositionViewWidgetList::nettoPrice()
   return res;
 }
 
-void PositionViewWidget::slotSetPositionNormal()
+QString PositionViewWidget::cleanKindString(const QString& src)
 {
-  lKind->hide();
-  lKind->setPixmap( QPixmap() );
-  mKind = Normal;
-
-  cleanKindString();
-  slotRefreshPrice();
-  emit positionModified();
+    QString current {src};
+    if ( current.startsWith( kindLabel( Alternative ) ) ) {
+        current.remove( 0, kindLabel(Alternative).length() );
+    } else if ( current.startsWith( kindLabel( Demand ) ) ) {
+        current.remove( 0, kindLabel(Demand).length());
+    }
+    return current;
 }
 
-void PositionViewWidget::cleanKindString()
+void PositionViewWidget::slotSetPositionKind(Kind kind, bool alterText)
 {
-  QString current = m_teFloskel->toPlainText();
-  bool touched = false;
+    QString tt;
+    QIcon icon;
+    bool showLabel {false};
+    Kind oldKind = mKind;
 
-  if ( current.startsWith( kindLabel( Alternative ) ) ) {
-    current.remove( 0, QString( kindLabel( Alternative ) ).length() );
-    touched = true;
-  } else if ( current.startsWith( kindLabel( Demand ) ) ) {
-    current.remove( 0, QString( kindLabel( Demand ) ).length() );
-    touched = true;
-  }
+    mKind = kind;
+    if (kind == Kind::Normal) {
 
-  if ( touched ) {
-    m_teFloskel->setText( current );
-  }
-}
+    } else if (kind == Kind::Demand) {
+        tt = i18n( "This item is either completely optional or its "
+                   "amount varies depending on the needs.<br/><br/>"
+                   "Use the item toolbox to change the item type." );
+        showLabel = true;
+        icon = DefaultProvider::self()->icon("arrow-move-right");
+    } else if (kind == Kind::Alternative) {
+        tt = i18n( "This is an alternative item.<br/><br/>"
+                   " Use the position toolbox to change the item type." );
+        showLabel = true;
+        icon = DefaultProvider::self()->icon("arrow-ramp-right");
+    }
+    showLabel ? lKind->show() : lKind->hide();
+    lKind->setToolTip(tt);
+    lKind->setPixmap(icon.pixmap(QSize(20,20)));
 
-void PositionViewWidget::slotSetPositionAlternative()
-{
-  lKind->show();
-  lKind->setToolTip( i18n( "This is an alternative item.<br/><br/>"
-                           " Use the position toolbox to change the item type." ) );
-  lKind->setPixmap( QIcon::fromTheme( "kraft_alternative" ).pixmap(QSize(20,20)));
-  mKind = Alternative;
-  slotRefreshPrice();
-
-  cleanKindString();
-
-  m_teFloskel->setText( kindLabel( Alternative ) + m_teFloskel->toPlainText() );
-
-  emit positionModified();
-}
-
-void PositionViewWidget::slotSetPositionDemand()
-{
-  lKind->show();
-  lKind->setToolTip( i18n( "This item is either completely optional or its "
-                           "amount varies depending on the needs.<br/><br/>"
-                           "Use the item toolbox to change the item type." ) );
-  lKind->setPixmap( QIcon::fromTheme("kraft_demand").pixmap(QSize(20,20)));
-  mKind = Demand;
-  slotRefreshPrice();
-
-  cleanKindString();
-  m_teFloskel->setText( kindLabel( Demand ) + m_teFloskel->toPlainText() );
-
-  emit positionModified();
+    if (alterText) {
+        QString text =  m_teFloskel->toPlainText();
+        if (oldKind == Kind::Normal) {
+            QString pre;
+            if (kind == Kind::Alternative) {
+                pre = kindLabel(Kind::Alternative);
+            } else if (kind == Kind::Demand) {
+                pre = kindLabel(Kind::Demand);
+            }
+            if (!pre.isEmpty()) {
+                m_teFloskel->setPlainText(pre + text);
+            }
+        } else {
+              // from demand to normal or alternative for example
+            if (kind == Kind::Normal) {
+                text = cleanKindString(text);
+            } else {
+                text = kindLabel(kind) + cleanKindString(text);
+            }
+            m_teFloskel->setPlainText(text);
+        }
+    }
 }
 
 // The technical label
-QString PositionViewWidget::kindString( Kind k ) const
+// Do not
+QString PositionViewWidget::techKindString( Kind kind)
 {
-  Kind kind = k;
 
-  if ( kind == Invalid ) kind = mKind;
+  if ( kind == Invalid ) {
+      qDebug() << "Invalid Kind set";
+  }
+  if ( kind == Normal )      return QStringLiteral( "Normal" );
+  if ( kind == Demand )      return QStringLiteral( "Demand" );
+  if ( kind == Alternative ) return QStringLiteral( "Alternative" );
 
-  if ( kind == Normal )      return QString::fromLatin1( "Normal" );
-  if ( kind == Demand )      return QString::fromLatin1( "Demand" );
-  if ( kind == Alternative ) return QString::fromLatin1( "Alternative" );
+  return QStringLiteral( "Invalid" );
+}
 
-  return QString::fromLatin1( "unknown" );
+PositionViewWidget::Kind PositionViewWidget::techStringToKind( const QString& kindStr )
+{
+    if (kindStr == techKindString(Normal)) {
+        return Kind::Normal;
+    } else if (kindStr == techKindString(Demand)) {
+        return Kind::Demand;
+    } else if (kindStr == techKindString(Alternative)) {
+        return Kind::Alternative;
+    }
+    return Kind::Invalid;
 }
 
 // The label that is prepended to a positions text
-QString PositionViewWidget::kindLabel( Kind k ) const
+QString PositionViewWidget::kindLabel( Kind k )
 {
   Kind kind = k;
 
-  if ( kind == Invalid ) kind = mKind;
-
   QString re;
   if ( kind == Normal ) {
     re = KraftSettings::self()->normalLabel();
@@ -680,7 +696,7 @@ QString PositionViewWidget::kindLabel( Kind k ) const
   }
 
   if ( ! re.endsWith( ": " ) ) {
-    re += QString::fromLatin1( ": " );
+    re += QStringLiteral( ": " );
   }
   return re;
 }
@@ -700,7 +716,7 @@ void PositionViewWidget::paintEvent ( QPaintEvent*)
       TagTemplate tagTemplate = TagTemplateMan::self()->getTagTemplate( tag );
 
       const QColor c = tagTemplate.color();
-      // qDebug() << "color: " << c.red() << ", " << c.green() << ", " << c.blue() << endl;
+      // qDebug() << "color: " << c.red() << ", " << c.green() << ", " << c.blue();
       painter->setBrush( c );
 
       int starty = 6+cnt*share;
