@@ -129,10 +129,10 @@ bool TagTemplateMan::writeTemplate( const TagTemplate& tt )
   }
 
   if ( cnt == -1 ) {
-    qCritical() << "DB does not know the number of affected rows, poor!" << endl;
+    qCritical() << "DB does not know the number of affected rows, poor!";
     ret = false;
   } else if ( cnt == 0 ) {
-    // qDebug () << "need to insert the tag template into db" << endl;
+    // qDebug () << "need to insert the tag template into db";
     QSqlQuery qi;
     qi.prepare( "INSERT INTO tagTemplates (name, sortKey, description, color) VALUES "
                 "( :name, :sortKey, :desc, :col )" );
